# Copyright 2007, Todd Burch - Smustard.Com   http://www.smustard.com
=begin
Smustard.com(tm) Ruby Script End User License Agreement
This is a License Agreement is between you and Smustard.com.
If you download, acquire or purchase a Ruby Script or any freeware or any other product (collectively "Scripts") from Smustard.com, then you hereby accept and agree to all of the following terms and conditions:
Smustard.com, through its agreements with individual script authors, hereby grants you a permanent, worldwide, non-exclusive, non-transferable, non-sublicensable use license with respect to its rights in the Scripts.
If you are an individual, then you may copy the Scripts onto any computer you own at any location.
If you are an entity, then you may not copy the Scripts onto any other computer unless you purchase a separate license for each computer and you must have a separate license for the use of the Script on each computer.
You may not alter, publish, market, distribute, give, transfer, sell or sublicense the Scripts or any part of the Scripts.
This License Agreement is governed by the laws of the State of Texas and the United States of America.
You agree to submit to the jurisdiction of the Courts in Houston, Harris County, Texas, United States of America, to resolve any dispute, of any kind whatsoever, arising out of, involving or relating to this License Agreement.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
This software has not been endorsed or sanctioned by Google.  Any comments, concerns or issues about this software
or the affects of this software should be not directed to Google, but to Smustard.com.
# Name :          scene_rename.rb 1.0
# Description :   Renames all scenes in a model into numerical sequence
# Author :        Todd Burch   http://www.smustard.com
#
# Usage :         1. Active the Tool from the View
#
#                 If the naming convention already in use is not apparently obvious,
#                 the user will be prompted to speciy a prefix for the names.
#
# Date :          02.Aug.2007
# Type :          Tool
# History:        1.0 (02.Aug.2007) - first version
#
#
#-----------------------------------------------------------------------------
=end
UI.messagebox("scene_rename loaded!")
require 'sketchup.rb'
class SceneRename
  def initialize()
	# Get an array of all the scene names in the model.
	scenes = Sketchup.active_model.pages
	if scenes.count==0 then
		UI.messagebox("There are no scenes defined!")
		return
	end
	# Go through all the scenes, grabbing all the names
	all_names = Array.new
	scenes.each {|p|
		all_names.push(p.name)
	}
	minlength = scenes.map {|s| s.name.length}.min
	# Figure out the naming convention. Maybe.
	common = nil
	if (all_names.first[0,1]=='!') then   # force use of the first name
		common = all_names.first.split[0] # use everything up to the first blank
		common = common[1,common.length]  # remove the !
	else   # figure out the prefix
		common = all_names.first[0,minlength] # get the portion of the first item
		breakout = false
		1.upto(minlength) {|i|
			all_names.each {|n|
				# figure out what part of the next name matches the "convention"
				next if n[0,i].downcase == common.downcase[0,i]
				common = common[0,i-1]   # remove the last char
				breakout = true
			}
			break if breakout;
		}
		common = "Scene" if !common
		common.strip!   # don't allow extra blanks to pile up
		common = "Scene" if common.empty?
	end
	Sketchup.active_model.start_operation "Scene Resequence"
	1.upto(scenes.count) {|i|
		scenes[i-1].name = common + ' ' + i.to_s
	}
	Sketchup.active_model.commit_operation 	
	return
  end # initialize
end # class SceneRename
#-----------------------------------------------------------------------------
if not file_loaded?(__FILE__)
  UI.menu("View").add_item("Rename|Renumber-Scenes"){SceneRename.new()}
end
#-----------------------------------------------------------------------------
file_loaded(__FILE__)
